@@ -101,6 +101,7 @@ class TaskMessaging:
             message = args[0] % tuple(args[1:])
         else:
             message = args[0]
+        logger.debug(message)
         try:
             if not (task or self.task):
                 raise models.Task.DoesNotExist('No task was supplied.')
@@ -172,6 +173,9 @@ class RuleContext:
     def rule_name(self, value):
         self._rule_name = value
 
+    def __str__(self):
+        return str(self._context)
+
 
 class DependencyMixin:
     def get_running_tasks(self):
@@ -245,7 +249,7 @@ class Rule(TaskMessaging):
 
         :param data: The data to be handled by each of the steps in the rule.
         '''
-        self.info(_('Beginning execution of the Rule.'))
+        self.info(_('Beginning execution of Rule {0}'.format(self.db_rule.name)))
         try:
             if len(self.steps) == 0:
                 self.error(
@@ -286,6 +290,8 @@ class Rule(TaskMessaging):
         :param step: The step that failed.
         '''
         try:
+            self.db_task.STATUS = 'FAILED'
+            self.db_task.save()
             self.error('Performing step failure routine.')
             step.on_failure()
         except Exception:
